<?php
namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\DashboardService;
use SM\Traits\TResponse;

class DashboardController extends SMCrud {

  use TResponse;

  protected $DashboardService;

  public function __construct($crudService, $environment, DashboardService $DashboardService) {
        parent::__construct($crudService, $environment);
        $this->DashboardService = $DashboardService;
  }

  public function getApprovedContracts(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getApprovedContracts($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getTerminatedContracts(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getTerminatedContracts($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getRenegotiatedContracts(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getRenegotiatedContracts($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getContractsCloseToExpiration(Request $request, Response $response){
    try {
        $data = $this->DashboardService->getContractsCloseToExpiration();
        $this->sendResponse($data, 200);
      } catch (Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
     }
  }

  public function getContractsPendingBilling(Request $request, Response $response){
    try {
        $data = $this->DashboardService->getContractsPendingBilling($request->getParameters());
        $this->sendResponse($data, 200);
      } catch (Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
     }
  }

  public function getChartBusinessPartner(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getChartBusinessPartner($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getChartBillingScope(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getChartBillingScope($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getChartContractItems(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getChartContractItems($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getMonthlyHistory(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->getMonthlyHistory();
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getBusinessPartnerDetailed(Request $request, Response $response){
      $grid = $this->DashboardService->getBusinessPartnerDetailed($request->getParameters());
      $dtsVal = new DataSet('grid', $grid);
      $response->addDataSet($dtsVal);
  }

  public function getBillingScopeDetailed(Request $request, Response $response){

      $grid = $this->DashboardService->getBillingScopeDetailed($request->getParameters());
      $dtsVal = new DataSet('grid', $grid);
      $response->addDataSet($dtsVal);
  }

  public function getPartners(Request $request, Response $response){
    try {
        $data = $this->DashboardService->getPartners();
        $this->sendResponse($data, 200);
      } catch (Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
     }
  }

  public function getScopes(Request $request, Response $response){
    try {
        $data = $this->DashboardService->getScopes();
        $this->sendResponse($data, 200);
      } catch (Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
     }
  }

  public function amountOfProposalAccepted(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->amountOfProposalAccepted($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function valueOfAcceptedProposal(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->valueOfAcceptedProposal($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function valueOfAcceptedProposalXBusinessPartner(DTO\Request $request, DTO\Response $response) {
      $chart = $this->DashboardService->valueOfAcceptedProposalXBusinessPartner($request->getParameters());
      $dtsVal = new DataSet('chart', $chart);
      $response->addDataSet($dtsVal);
  }

  public function getContractItemsDetailed(Request $request, Response $response){
      $grid = $this->DashboardService->getContractItemsDetailed($request->getParameters());
      $dtsVal = new DataSet('grid', $grid);
      $response->addDataSet($dtsVal);
  }

  public function getContractItems(Request $request, Response $response){
    try {
        $data = $this->DashboardService->getContractItems();
        $this->sendResponse($data, 200);
      } catch (Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
     }
  }
}
?>