/* eslint-disable */
import {
  Config, IEventParam, Loader, Metadata,
} from '@zeedhi/core';
import {
  AutoNumeric, ApexChart, Button, DateRange, Modal, ModalService, Tabs,
} from '@zeedhi/common';

export class DashboardController{
  private modalFilter!: Modal;

  private openingMode: any;

  public ContractsController = Loader.getInstance('FrameContractsController');

  public ProposalController = Loader.getInstance('FrameProposalController');

  public BillingControlller = Loader.getInstance('FrameBillingController');

  public async openModal({ component }: any) {
    this.modalFilter = await ModalService.createFromJson('/dashboard/modal/modal-filter', true);
    this.modalFilter.show();
    this.openingMode = component.name;
  }

  public closeModal() {
    this.modalFilter.hide();
    this.modalFilter?.destroy();
  }

  public filterGeneric({component}: any) {
    const ConjuntoTabs = Metadata.getInstance<Tabs>('tabs-dashboard');

    if (ConjuntoTabs.tabs[ConjuntoTabs.activeTab].name === 'tab-contract') {
      this.ContractsController.mountChartAprovedContracts({ component });
      this.ContractsController.mountChartTerminatedContracts({ component });
      this.ContractsController.mountChartRenegotiatedContracts({ component });
      this.ContractsController.setFilterCard({ component });
    } else if (ConjuntoTabs.tabs[ConjuntoTabs.activeTab].name === 'tab-proposal') {
      this.ProposalController.valueOfAcceptedProposalXBusinessPartner({ component });
      this.ProposalController.amountOfProposalAccepted({ component });
      this.ProposalController.valueOfAcceptedProposal({ component });
    } else if (ConjuntoTabs.tabs[ConjuntoTabs.activeTab].name === 'tab-billing') {
      this.BillingControlller.mountChartBusinessPartner({ component });
      this.BillingControlller.mountChartBillingScope({ component });
      this.BillingControlller.mountChartContractItems({ component });
    }
  }

  public filterModal() {
    const dateRange = {
      component: Metadata.getInstance<DateRange>('selectDate-modalFilter'),
    };

    if(this.openingMode === 'btn-filter-ApprovedContracts') {
      this.ContractsController.mountChartAprovedContracts(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-terminatedContracts') {
      this.ContractsController.mountChartTerminatedContracts(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-contractsPendingBilling') {
      this.ContractsController.setFilterCard(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-renegotiatedContracts') {
      this.ContractsController.mountChartRenegotiatedContracts(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-valueOfAcceptedProposalXBusinessPartner') {
      this.ProposalController.valueOfAcceptedProposalXBusinessPartner(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-amountOfProposalAccepted') {
      this.ProposalController.amountOfProposalAccepted(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-valueOfAcceptedProposal') {
      this.ProposalController.valueOfAcceptedProposal(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-businessPartner') {
      this.BillingControlller.mountChartBusinessPartner(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-billingScope') {
      this.BillingControlller.mountChartBillingScope(dateRange);
      this.closeModal();
    } else if (this.openingMode === 'btn-filter-contractItems') {
      this.BillingControlller.mountChartContractItems(dateRange);
      this.closeModal();
    }
  }

  public nextPage({ component }: any) {
    component.parent.datasource.page += 1;
    if (component.parent.paginationLength === component.parent.datasource.page) {
      component.disabled = true;
    }
    component.parent.datasource.get();
    Metadata.getInstance<Button>(`previous-page_${component.name.split('_')[1]}`).disabled = false;
  }

  public previousPage({ component }: any) {
    if (component.parent.datasource.page > 1) {
      component.parent.datasource.page -= 1;
      if (component.parent.datasource.page === 1) {
        component.disabled = true;
      }
      component.parent.datasource.get();
      Metadata.getInstance<Button>(`next-page_${component.name.split('_')[1]}`).disabled = false;
    }
  }

   public sendMessage(data:Object) {
     console.log(data);
    window.parent.postMessage({
        type: 'DashboardNext-charts',
        realData: data,
    }, window.location.ancestorOrigins[0]);
  }

  public chartMounted({ component }: IEventParam<ApexChart>) {
 //   const page = component.name.split('_')[1];
    const options = {
      chart: {
        events: {
          click: this.clickEvent.bind(this),
        },
      },
    };
    component.updateChart(options);
  }

  public clickEvent({ toElement }: any) {
    if(toElement.innerText && toElement.innerText != undefined) {
      const page = Metadata.getInstance<Tabs>('tabs-dashboard');
      const pageActive = page.tabs[page.activeTab].tabTitle;
      const data = {
        ESCOPO: toElement.innerText,
        PAGINA: pageActive,
      }
      this.sendMessage(data);
    }
  }

  public formatPieDataQtd(val: number, opts: any) {
    return `${opts.w.config.series[opts.seriesIndex]} - ${val.toFixed(2)}%`;
  }

  public formatPieDataValue(val: number, opts: any) {
    return `R$ ${opts.w.config.series[opts.seriesIndex].toFixed(2)} - ${val.toFixed(2)}%`;
  }

  public formatBarData(val: number) {
    return AutoNumeric.format(val, Config.masks.currencyMask);
  }
}
